#-----------------------------------------------------------------------
# Rhrer-Plot.
#
# Aufruf:
#
#   call 'plot.plt' '<DATEI>' '<SPALTENNUMMERN Y>' '<SPALTENNUMMERN Y2>'
#
#   DATEI              - Datei mit Messdaten,
#   SPALTENNUMMERN Y   - Menge von Spaltennummern, linke y-Achse,
#   SPALTENNUMMERN Y2  - Menge von Spaltennummern, rechte y2-Achse.
#
#
# Beispiel:
#
#   call 'plot.plt' 'myfile.dat' '2 4 5' '6'
#
#
# 2020-05-18, s.reiser@tu-braunschweig.de
#-----------------------------------------------------------------------

# Parameteranzahl prfen und ggf. abbrechen.
if (ARGC != 3) {
  print "3 arguments required:" 
  print "  1) data-file,"
  print "  2) set of column numbers (plotted against y-axis),"
  print "  3) set of column numbers (plotted against y2-axis)."
  exit
}
else {
  theFile = ARG1
  theCols = ARG2
  theCols2 = ARG3
}

reset

set termoption noenhanced

set datafile separator ";"

set xdata time
#set format x "%tM:%S"
set format x "%tH:%M"

# Zeitstempel des ersten Datensatzes aus Datei holen:
set term push
set term unknown
set timefmt "%Y-%m-%d %H:%M:%S"  # Zeitformat: ISO.
plot theFile using 1:2
timestamp = GPVAL_DATA_X_MIN
set term pop

set y2tics
set tics out scale 2
set my2tics default
set mxtics 

set yrange [0:*]

if (words(theCols) > 0) {
   set ytics nomirror 1
   set mytics 5
   set grid xtics y2tics ytics
   set ylabel "Drehmoment [Ncm]"
} else {
   unset ytics
   set y2tics mirror
   set grid xtics y2tics
}

set key bottom

set xlabel "Zeit [h:mm]"
set y2label "Drehzahl [rpm]; Temperatur [C]"


set timefmt "%s"  # Zeitformat: Sekunden seit t0.
set title '"' . theFile . '"' . strftime(" (%F, %R Uhr)",timestamp)

# Funktion: Holt Element aus Liste von Integer-Werten.
numberAt(s, n) = words(s) == 0 ? -1 : int(word(s,n))

plot for [i=1:words(theCols)] theFile using 2:numberAt(theCols,i)      \
         axes x1y1 w l ls (numberAt(theCols,i)-1) lw 2 t colu          \
   , for [i=1:words(theCols2)] theFile using 2:numberAt(theCols2,i)    \
         axes x1y2 w l ls (numberAt(theCols2,i)-1) lw 2 t colu
